@@ -409,7 +409,7 @@ class ResponseObject(object):
 		keys,
 	):
 		defaults = {}
-		if isinstance(keys, (dict, Dictionary)):
+		if isinstance(keys, (dict, Files.Dictionary, ResponseObject)):
 			if isinstance(keys, dict):
 				defaults = dict(keys)
 				keys = list(keys.keys())
@@ -420,13 +420,16 @@ class ResponseObject(object):
 			keys = [keys]
 		unpacked = []
 		for key in keys:
-			value, set = None, False
+			value, set = None, True
 			try: 
 				value = self[key]
-				set = True
-			except KeyError: value = defaults[key]
+			except KeyError: 
+				try:
+					value = defaults[key]
+				except KeyError: 
+					set = False
 			if not set:
-				raise exceptions.UnpackError(f"{self.instance()} does not contain attribute [{key}].")
+				raise exceptions.UnpackError(f"Dictionary does not contain attribute [{key}].")
 			unpacked.append(value)
 		return unpacked
 	def remove(self, keys=[], values=[], save=False):
